species.analysis package
========================

Submodules
----------

species.analysis.fit\_model module
----------------------------------

.. automodule:: species.analysis.fit_model
    :members:
    :undoc-members:
    :show-inheritance:

species.analysis.fit\_planck module
-----------------------------------

.. automodule:: species.analysis.fit_planck
    :members:
    :undoc-members:
    :show-inheritance:

species.analysis.fit\_spectrum module
-------------------------------------

.. automodule:: species.analysis.fit_spectrum
    :members:
    :undoc-members:
    :show-inheritance:

species.analysis.photometry module
----------------------------------

.. automodule:: species.analysis.photometry
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: species.analysis
    :members:
    :undoc-members:
    :show-inheritance:
